@@ -136,6 +136,7 @@ class Interpreter:
         if var.Value.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
             raise exceptions.RuntimeError(f'Type error, index not supported on {var.Value.Type}. ({var.Name}).', idx.Token.Location, self.filename)    
         val = var.Value
+        pred = var.Value
         expr = idx
         vind = []
         while expr.ExprType != types.ExprTypes.VariableIndexStart:
@@ -143,12 +144,14 @@ class Interpreter:
             expr = expr.Left
         lng = len(vind)
         cnt = 0
+        index_as_str = ''
         for ind in vind:
             if val.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
-                raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name})', ind.Token.Location, self.filename)    
+                if not(val.Type == types.VariableTypes.Nil and pred != val and pred.Type == types.VariableTypes.Record):
+                    raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name}{index_as_str})', ind.Token.Location, self.filename)    
             if ind.ExprType == types.ExprTypes.NewArrayIndex:
                 if val.Type != types.VariableTypes.Array:
-                    raise exceptions.RuntimeError(f'Type error, append not supported on {val.Type}. ({var.Name})', ind.Token.Location, self.filename)
+                    raise exceptions.RuntimeError(f'Type error, append not supported on {val.Type}. ({var.Name}{index_as_str})', ind.Token.Location, self.filename)
                 val.Value.append(value)
                 return
             i = self.InterpretExpression(ind, scope)
@@ -158,12 +161,20 @@ class Interpreter:
                         val.Value[i.Value] = value
                         return
                     else:
-                        raise exceptions.RuntimeError(f'Index ({i.Value}) not found. ({var.Name}).', ind.Token.Location, self.filename)
+                        raise exceptions.RuntimeError(f'Index ({i.Value}) not found. ({var.Name}{index_as_str}).', ind.Token.Location, self.filename)
             elif val.Type == types.VariableTypes.Array or val.Type == types.VariableTypes.String:
                 if i.Type != types.VariableTypes.Int:
                     raise exceptions.RuntimeError(f'Invalid index type ({i.Type}), Int index type required. ({var.Name}).', ind.Token.Location, self.filename)
                 if i.Value < 0 or i.Value >= len(val.Value):
-                    raise exceptions.RuntimeError(f'Index ({i.Value}) is out of range. ({var.Name})', ind.Token.Location, self.filename)
+                    raise exceptions.RuntimeError(f'Index ({i.Value}) is out of range. ({var.Name}{index_as_str})', ind.Token.Location, self.filename)
+            elif val.Type == types.VariableTypes.Nil and pred.Type == types.VariableTypes.Record:
+                if cnt == lng -1:
+                    val.Value[i.Value] = value_item.ValueItem().NilValue()
+                    return
+                else:
+                    raise exceptions.RuntimeError(f'Invalid index ({i.Type}) on nil value. ({var.Name}{index_as_str}).', ind.Token.Location, self.filename)
+            pred = val
+            index_as_str = f'{index_as_str}[{i.Value}]'
             val = val.Value[i.Value]
             cnt+=1
 
