@@ -163,6 +163,13 @@ class ValueItem:
 
 
 
+    def NilValue(self):
+        self.Token = token.LexToken.nullToken()
+        self.Type = types.VariableTypes.Nil
+        self.Value = types.VariableTypes.Nil
+
+
+
     def __repr__(self) -> str:
         return f'ValueItem(token={self.Token}, value={self.Value}, type={self.Type});'
 
